@@ -18,11 +18,6 @@ attr param    => sub { [] };
 attr to       => undef;
 attr dest     => undef;
 
-# helpers for matching different types of wildcards
-sub __noslash  { 1 == grep { $_[0] eq $_ } ':', '?' }
-sub __matchall { 1 == grep { $_[0] eq $_ } '*', '>' }
-sub __optional { 1 == grep { $_[0] eq $_ } '?', '>' }
-
 sub new {
     my $class = shift;
     my $self = $class->SUPER::new(@_);
@@ -46,37 +41,23 @@ sub _fix_pattern {
 
 sub _rep_regex {
     my ( $self, $char, $switch, $token ) = @_;
-    my $re;
 
-    my $optional = sub {
-        return unless __optional($switch);
-        $re = "(?:$re)" if $char eq '/';
-        $re .= '?';
-    };
+    push @{$self->{_tokens}}, $token;
 
-    # no token - only valid for the wildcard * and slurpy >
-    if ( !defined $token ) {
-
-        # do nothing
-        return $char . $switch
-            unless __matchall($switch);
-
-        $re = $char . '(.+)';
-    }
-    else {
-        push @{$self->{_tokens}}, $token;
-
-        my ( $prefix, $suffix ) = ( "(?<$token>", ')' );
-        if ( __noslash($switch) ) {
-            $re = $char . $prefix . ( $self->check->{$token} // '[^\/]+' ) . $suffix;
+    my ( $a, $b, $r ) = ( "(?<$token>", ')', undef );
+    for ($switch) {
+        if ( $_ eq ':' || $_ eq '?' ) {
+            $r = $a . ( $self->check->{$token} // '[^\/]+' ) . $b
         }
-        elsif ( __matchall($switch) ) {
-            $re = $char . $prefix .  ( $self->check->{$token} // '.+' ) . $suffix;
+        if ( $_ eq '*' ) {
+            $r = $a . '.+' . $b
         }
     }
 
-    $optional->();
-    return $re;
+    $char = $char . '?' if $char eq '/' && $switch eq '?';
+    $r .= '?' if $switch eq '?';
+
+    return $char . $r;
 }
 
 sub _build_regex {
@@ -85,7 +66,7 @@ sub _build_regex {
 
     return $self->pattern if ref $self->pattern eq 'Regexp';
 
-    my $PAT = '(.?)([:*?>])(\w+)?';
+    my $PAT = '(.?)([:*?])(\w+)';
     my $pattern =  $self->pattern;
 
     # Curly braces and brackets are only used for separation.
@@ -103,22 +84,14 @@ sub _build_regex {
 
 sub _rep_build {
     my ( $self, $switch, $token, %args ) = @_;
-
-    if (!defined $token) {
-        return $switch unless __matchall($switch);
-        $token = $switch;
-    }
-
     my $rep = $args{$token} // $self->defaults->{$token} // '';
-    if ( !__optional($switch) && !$rep) {
+    if ($switch ne '?' && !$rep) {
         return '{?' . $token . '}';
     }
-
     my $check = $self->check->{$token};
     if ( $check && $args{$token} !~ $check ) {
         return '{!' . $token . '}';
     }
-
     return $rep;
 }
 
@@ -131,9 +104,9 @@ sub build {
         return;
     }
 
-    my $PAT = '([:*?>])(\w+)?';
+    my $PAT = '([:*?])(\w+)';
     $pattern =~ s/{?$PAT}?/$self->_rep_build($1, $2, %args)/eg;
-    if ($pattern =~ /{([!?])(\w+|[*>])}/) {
+    if ($pattern =~ /{([!?])(\w+)}/) {
         carp $1 eq '!'
             ? "Field $2 doesn't match checks"
             : "Default value for field $2 is missing";
@@ -157,7 +130,7 @@ sub match {
         @matched = map { $named{$_} } @{ $self->{_tokens} };
     }
     elsif ( $has_matches ) {
-        @matched = map { length($_ // '') ? $_ : undef } @matched;
+        @matched = map { length ? $_ : undef } @matched;
     }
     else {
         @matched = ();
@@ -329,7 +302,6 @@ was successful, this sub will return a true value and the L</named> and L</param
 attributes will be initialized with the names and values of the matched placeholders.
 
 =head2 build
-
 C<build( %args )>
 
 Builds a URL from a pattern.
@@ -337,15 +309,6 @@ Builds a URL from a pattern.
     my $p = Kelp::Routes::Patters->new( pattern  => '/:id/:line/:row' );
     $p->build( id => 100, line => 5, row => 8 ); # Returns '/100/5/8'
 
-If the pattern contains an unnamed wildcard C<*> or slurpy C<< > >>, then it
-should be built like this:
-
-    my $p = Kelp::Routes::Patters->new( pattern  => '/hello/*/>' );
-    $p->build( '*' => 'kelp', '>' => 'world' ); # Returns '/hello/kelp/world'
-
-If the pattern contains more than one unnamed items, then you should
-probably give them some names.
-
 =head1 ACKNOWLEDGEMENTS
 
 This module was inspired by L<Routes::Tiny>.
